==> samurai-graph-src-1.0.0.zip: samurai-graph-src-1.0.0/src/jp/riken/brain/ni/samuraigraph/application/SGIApplicationConstants.java <==

package jp.riken.brain.ni.samuraigraph.application;

/**
 * Constants used in this application.
 *
 */
public interface SGIApplicationConstants
{

	/**
	 * Major version number.
	 */
	public static final int MAJOR_VERSION_NUMBER = 1;


	/**
	 * Minor version number.
	 */
	public static final int MINOR_VERSION_NUMBER = 0;


	/**
	 * Micro version number.
	 */
	public static final int MICRO_VERSION_NUMBER = 0;


	/**
	 * Default class name of axis figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_AXIS_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGAxisElement";

	/**
	 * Default class name of sxy-graph figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_SXY_GRAPH_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGSXYGraphElement";

	/**
	 * Default class name of vxy-graph figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_VXY_GRAPH_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGVXYGraphElement";

	/**
	 * Default class name of string figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_STRING_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGStringElement";

	/**
	 * Default class name of legend figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_LEGEND_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGLegendElement";

	/**
	 * Default class name of axis break figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_AXIS_BREAK_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGAxisBreakElement";

	/**
	 * Default class name of significant difference figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_SIGNIFICANT_DIFFERENCE_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGSignificantDifferenceElement";

	/**
	 * Default class name of timing line figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_TIMING_LINE_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGTimingLineElement";

	/**
	 * Default class name of grid figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_GRID_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGGridElement";

	/**
	 * Default class name of shape figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_SHAPE_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGShapeElement";

}

==> samurai-graph-src-1.0.1.zip: samurai-graph-src-1.0.1/src/jp/riken/brain/ni/samuraigraph/application/SGIApplicationConstants.java <==

package jp.riken.brain.ni.samuraigraph.application;

/**
 * Constants used in this application.
 *
 */
public interface SGIApplicationConstants
{

	/**
	 * Application resource directory
	 */
	public static final String APPLICATION_RESOURCE_DIRECTORY = "resources";
	
	/**
	 * Application property File
	 */
	public static final String APPLICATION_PROPERTY_FILENAME = "samurai-graph.properties";

	/**
	 * Version string in property file
	 */
	public static final String VERSION_PROPERTY_NAME = "samurai-graph.version";
	
	
	/**
	 * Default class name of axis figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_AXIS_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGAxisElement";

	/**
	 * Default class name of sxy-graph figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_SXY_GRAPH_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGSXYGraphElement";

	/**
	 * Default class name of vxy-graph figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_VXY_GRAPH_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGVXYGraphElement";

	/**
	 * Default class name of string figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_STRING_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGStringElement";

	/**
	 * Default class name of legend figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_LEGEND_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGLegendElement";

	/**
	 * Default class name of axis break figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_AXIS_BREAK_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGAxisBreakElement";

	/**
	 * Default class name of significant difference figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_SIGNIFICANT_DIFFERENCE_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGSignificantDifferenceElement";

	/**
	 * Default class name of timing line figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_TIMING_LINE_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGTimingLineElement";

	/**
	 * Default class name of grid figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_GRID_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGGridElement";

	/**
	 * Default class name of shape figure element.
	 */
	public static final String DEFAULT_CLASS_NAME_OF_SHAPE_ELEMENT
		= "jp.riken.brain.ni.samuraigraph.figure.java2d.SGShapeElement";

}
